@@ -1,4 +1,4 @@
-# $Id: emoncms.py 1185 2014-12-13 02:18:38Z mwall $
+# $Id: emoncms.py 1296 2015-03-23 21:50:44Z mwall $
 # Copyright 2013-2014 Matthew Wall
 
 """
@@ -63,7 +63,7 @@ import weewx.restx
 import weewx.units
 from weeutil.weeutil import to_bool, accumulateLeaves
 
-VERSION = "0.7"
+VERSION = "0.9"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -172,42 +172,20 @@ class EmonCMS(weewx.restx.StdRESTbase):
         # for backward compatibility: 'station' is now 'prefix'
         _compat(site_dict, 'station', 'prefix')
 
-        errs = []
-        try:
-            if site_dict.has_key('node'):
-                int(site_dict['node'])
-        except (TypeError, ValueError), e:
-            errs.append("node must be integer: %s" % e)
-
-        try:
-            if site_dict.has_key('append_units_label'):
-                site_dict['append_units_label'] = to_bool(
-                    site_dict['append_units_label'])
-        except ValueError, e:
-            errs.append("bad value for append_units_label: %s" % e)
-
-        if (site_dict.has_key('obs_to_upload') and
-            site_dict['obs_to_upload'].lower() not in ['all', 'none']):
-            errs.append("bad value for obs_to_upload")
+        site_dict.setdefault('node', None)
+        site_dict.setdefault('append_units_label', True)
+        site_dict.setdefault('augment_record', True)
+        site_dict.setdefault('obs_to_upload', 'all')
 
         usn = site_dict.get('unit_system', None)
         if usn is not None:
-            if usn in weewx.units.unit_constants:
-                site_dict['unit_system'] = weewx.units.unit_constants[usn]
-            else:
-                errs.append("unknown unit_system %s" % usn)
-
-        if errs:
-            for msg in errs:
-                logerr(msg)
-            logerr("Data will not be uploaded")
-            return
+            site_dict['unit_system'] = weewx.units.unit_constants[usn]
 
         if config_dict['StdRESTful']['EmonCMS'].has_key('inputs'):
             site_dict['inputs'] = dict(config_dict['StdRESTful']['EmonCMS']['inputs'])
 
         site_dict['manager_dict'] = weewx.manager.get_manager_dict(
-            config_dict['DataBindings'], config_dict['Databases'], 'wx_binding')
+            config_dict['DataBindings'],config_dict['Databases'],'wx_binding')
 
         self.archive_queue = Queue.Queue()
         self.archive_thread = EmonCMSThread(self.archive_queue, **site_dict)
@@ -216,7 +194,7 @@ class EmonCMS(weewx.restx.StdRESTbase):
 
         if 'prefix' in site_dict:
             loginf("prefix is %s" % site_dict['prefix'])
-        if 'node' in site_dict:
+        if 'node' in site_dict and site_dict['node'] is not None:
             loginf("node is %s" % site_dict['node'])
         if usn is not None:
             loginf("desired unit system is %s" % usn)
@@ -231,7 +209,7 @@ class EmonCMSThread(weewx.restx.RESTThread):
     _DEFAULT_SERVER_URL = 'http://emoncms.org/input/post.json'
 
     def __init__(self, queue, token, manager_dict,
-                 prefix=None, node=None, unit_system=None,
+                 prefix=None, node=None, unit_system=None, augment_record=True,
                  inputs={}, obs_to_upload='all', append_units_label=True,
                  server_url=_DEFAULT_SERVER_URL, skip_upload=False,
                  post_interval=None, max_backlog=sys.maxint, stale=None,
@@ -251,19 +229,21 @@ class EmonCMSThread(weewx.restx.RESTThread):
         self.token = token
         self.prefix = prefix
         self.node = node
-        self.upload_all = False if obs_to_upload.lower() == 'none' else True
+        self.upload_all = True if obs_to_upload.lower() == 'all' else False
         self.append_units_label = append_units_label
         self.inputs = inputs
         self.server_url = server_url
         self.skip_upload = to_bool(skip_upload)
         self.unit_system = unit_system
+        self.augment_record = augment_record
         self.templates = dict()
 
     def process_record(self, record, dbm):
-        r = self.get_record(record, dbm)
+        if self.augment_record:
+            record = self.get_record(record, dbm)
         if self.unit_system is not None:
-            r = weewx.units.to_std_system(r, self.unit_system)
-        url = self.get_url(r)
+            record = weewx.units.to_std_system(record, self.unit_system)
+        url = self.get_url(record)
         if self.skip_upload:
             loginf("skipping upload")
             return
